@@ -13,31 +13,44 @@ const (
 	logFile    = "gitlab-shell.log"
 )
 
+type MigrationConfig struct {
+	Enabled  bool     `yaml:"enabled"`
+	Features []string `yaml:"features"`
+}
+
 type Config struct {
 	RootDir   string
-	LogFile   string `yaml:"log_file"`
-	LogFormat string `yaml:"log_format"`
+	LogFile   string          `yaml:"log_file"`
+	LogFormat string          `yaml:"log_format"`
+	Migration MigrationConfig `yaml:"migration"`
 }
 
 func New() (*Config, error) {
-	cfg := Config{}
-
 	dir, err := os.Getwd()
 	if err != nil {
 		return nil, err
 	}
-	cfg.RootDir = dir
 
-	configBytes, err := ioutil.ReadFile(path.Join(cfg.RootDir, configFile))
+	return NewFromDir(dir)
+}
+
+func NewFromDir(dir string) (*Config, error) {
+	return newFromFile(path.Join(dir, configFile))
+}
+
+func newFromFile(filename string) (*Config, error) {
+	cfg := &Config{RootDir: path.Dir(filename)}
+
+	configBytes, err := ioutil.ReadFile(filename)
 	if err != nil {
 		return nil, err
 	}
 
-	if err := parseConfig(configBytes, &cfg); err != nil {
+	if err := parseConfig(configBytes, cfg); err != nil {
 		return nil, err
 	}
 
-	return &cfg, nil
+	return cfg, nil
 }
 
 // parseConfig expects YAML data in configBytes and a Config instance with RootDir set.
