@@ -1,10 +1,8 @@
-require_relative 'http_codes'
 require_relative 'httpunix'
 require_relative 'gitlab_logger'
+require_relative 'gitlab_net/errors'
 
 module HTTPHelper
-  include HTTPCodes
-
   READ_TIMEOUT = 300
   CONTENT_TYPE_JSON = 'application/json'.freeze
 
@@ -83,7 +81,8 @@ module HTTPHelper
       $logger.info('finished HTTP request', method: method.to_s.upcase, url: url, duration: Time.new - start_time)
     end
 
-    if response.code == "200"
+    case response
+    when Net::HTTPSuccess, Net::HTTPMultipleChoices
       $logger.debug('Received response', code: response.code, body: response.body)
     else
       $logger.error('Call failed', method: method.to_s.upcase, url: url, code: response.code, body: response.body)
